==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","ӹǹ駼ҹ");
define("_BROWSERS","Browsers");
define("_OPERATINGSYS","Operating System");
define("_UNKNOWN","Unknown");
define("_OTHER","Other / Unknown");
define("_MISCSTATS","Miscelaneous Stats");
define("_REGUSERS","Registered Users:");
define("_ACTIVEAUTHORS","Active Authors:");
define("_STORIESPUBLISHED","Stories Published:");
define("_SACTIVETOPICS","Active Topics:");
define("_COMMENTSPOSTED","Comments Posted:");
define("_SSPECIALSECT","Special Sections:");
define("_ARTICLESSEC","Articles in Sections:");
define("_LINKSINLINKS","Links in Web Links:");
define("_LINKSCAT","Categories in Links:");
define("_NEWSWAITING","News Waiting to be Published:");
define("_NUKEVERSION","PHP-Nuke Version:");
define("_SEARCHENGINES","Search Engines");
define("_BOTS","Robots/Spiders");
define("_STATS","Access Statistics");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","ӹǹ駼ҹ");
define("_BROWSERS","Browsers");
define("_OPERATINGSYS","Operating System");
define("_UNKNOWN","Unknown");
define("_OTHER","Other / Unknown");
define("_MISCSTATS","Miscelaneous Stats");
define("_REGUSERS","Registered Users:");
define("_ACTIVEAUTHORS","Active Authors:");
define("_STORIESPUBLISHED","Stories Published:");
define("_SACTIVETOPICS","Active Topics:");
define("_COMMENTSPOSTED","Comments Posted:");
define("_SSPECIALSECT","Special Sections:");
define("_ARTICLESSEC","Articles in Sections:");
define("_LINKSINLINKS","Links in Web Links:");
define("_LINKSCAT","Categories in Links:");
define("_NEWSWAITING","News Waiting to be Published:");
define("_NUKEVERSION","PHP-Nuke Version:");
define("_SEARCHENGINES","Search Engines");
define("_BOTS","Robots/Spiders");
define("_STATS","Access Statistics");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
